.. XIST documentation master file, created by
   sphinx-quickstart on Sun May 22 12:20:29 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to the XIST documentation!
==================================

.. include:: /../README.rst

Content
-------

.. toctree::
   :maxdepth: 1

   XIST
   UL4
   UL4ON
   URL_Howto
   make
   daemon
   sisyphus
   color
   misc
   pysql
   orasql
   nightshade
   scripts
   INSTALL
   DOWNLOAD
   NEWS
   MIGRATION
   Old
   Source


.. only:: html

   Cheeseshop info
   ---------------

   |version| |pythonversion| |format| |downloads| |license|

   .. |version|        image:: https://img.shields.io/pypi/v/ll-xist.svg
   .. |pythonversion|  image:: https://img.shields.io/pypi/pyversions/ll-xist.svg
   .. |format|         image:: https://img.shields.io/pypi/format/ll-xist.svg
   .. |downloads|      image:: https://img.shields.io/pypi/dm/ll-xist.svg
   .. |license|        image:: https://img.shields.io/pypi/l/ll-xist.svg


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
